import { route } from 'quasar/wrappers'
import {
  createRouter,
  createMemoryHistory,
  createWebHistory,
  createWebHashHistory
} from 'vue-router'
import routes from './routes'
// Import your authentication method or state management
import { useAuthStore } from '../stores/auth' // Example using Pinia store

export default route(function () {
  const createHistory = process.env.SERVER
    ? createMemoryHistory
    : (
        process.env.VUE_ROUTER_MODE === 'history'
          ? createWebHistory
          : createWebHashHistory
      )

  const Router = createRouter({
    scrollBehavior: () => ({ left: 0, top: 0 }),
    routes,
    history: createHistory(process.env.VUE_ROUTER_BASE)
  })

  // Global navigation guard
  Router.beforeEach((to, from, next) => {
    const authStore = useAuthStore()
    const isAuthenticated = authStore.isLoggedIn // Adjust based on your auth logic

    if (to.meta.requiresAuth && !isAuthenticated) {
      next('/login')
    } else {
      next()
    }
  })

  return Router
})
